@@ -16,12 +16,13 @@ import lookatme
 import lookatme.config
 import lookatme.log
 import lookatme.tui
+import lookatme.tutorial
 from lookatme.pres import Presentation
 from lookatme.schemas import StyleSchema
 
 
 @click.command("lookatme")
-@click.option("--debug", "debug", is_flag="True", default=False)
+@click.option("--debug", "debug", is_flag=True, default=False)
 @click.option(
     "-l",
     "--log",
@@ -29,6 +30,18 @@ from lookatme.schemas import StyleSchema
     type=click.Path(writable=True),
     default=os.path.join(tempfile.gettempdir(), "lookatme.log"),
 )
+@click.option(
+    "--tutorial",
+    "tutorial",
+    is_flag=False,
+    flag_value="all",
+    show_default=True,
+    help=(
+        "As a flag: show all tutorials. "
+        "With a value/comma-separated values: show the specific tutorials. "
+        "Use the value 'help' for more help"
+    )
+)
 @click.option(
     "-t",
     "--theme",
@@ -100,7 +113,7 @@ from lookatme.schemas import StyleSchema
     type=click.File("r"),
     nargs=-1,
 )
-def main(debug, log_path, theme, code_style, dump_styles,
+def main(tutorial, debug, log_path, theme, code_style, dump_styles,
          input_files, live_reload, extensions, single_slide, safe, no_ext_warn,
          ignore_ext_failure):
     """lookatme - An interactive, terminal-based markdown presentation tool.
@@ -115,8 +128,27 @@ def main(debug, log_path, theme, code_style, dump_styles,
     if len(input_files) == 0:
         input_files = [io.StringIO("")]
 
-    preload_exts = [x.strip() for x in extensions.split(',')]
-    preload_exts = list(filter(lambda x: x != '', preload_exts))
+    if tutorial:
+        if tutorial == "all":
+            tutors = ["general", "markdown"]
+        else:
+            tutors = [x.strip() for x in tutorial.split(",")]
+
+        theme_mod = __import__("lookatme.themes." + theme, fromlist=[theme])
+        lookatme.config.set_global_style_with_precedence(
+            theme_mod,
+            {},
+            code_style,
+        )
+        tutorial_md = lookatme.tutorial.get_tutorial_md(tutors)
+        if tutorial_md is None:
+            lookatme.tutorial.print_tutorial_help()
+            return 1
+
+        input_files = [io.StringIO(tutorial_md)]
+
+    preload_exts = [x.strip() for x in extensions.split(",")]
+    preload_exts = list(filter(lambda x: x != "", preload_exts))
     pres = Presentation(
         input_files[0],
         theme,
