@@ -6,11 +6,12 @@ source data in a terminal on the same slide.
 """
 
 
-from marshmallow import fields, Schema
 import os
 import subprocess
-import yaml
+from typing import Dict
 
+import yaml
+from marshmallow import Schema, fields
 
 import lookatme.config
 from lookatme.exceptions import IgnoredByContrib
@@ -30,29 +31,43 @@ def user_warnings():
 
 
 class YamlRender:
-    loads = lambda data: yaml.safe_load(data)
-    dumps = lambda data: yaml.safe_dump(data)
+    @staticmethod
+    def loads(data): return yaml.safe_load(data)
+    @staticmethod
+    def dumps(data): return yaml.safe_dump(data)
 
 
 class LineRange(Schema):
-    start = fields.Integer(default=0, missing=0)
-    end = fields.Integer(default=None, missing=None)
+    start = fields.Integer(dump_default=0, load_default=0)
+    end = fields.Integer(dump_default=None, load_default=None)
 
 
 class FileSchema(Schema):
     path = fields.Str()
-    relative = fields.Boolean(default=True, missing=True)
-    lang = fields.Str(default="auto", missing="auto")
-    transform = fields.Str(default=None, missing=None)
+    relative = fields.Boolean(dump_default=True, load_default=True)
+    lang = fields.Str(dump_default="auto", load_default="auto")
+    transform = fields.Str(dump_default=None, load_default=None)
     lines = fields.Nested(
         LineRange,
-        default=LineRange().dump(LineRange()),
-        missing=LineRange().dump(LineRange()),
+        dump_default=LineRange().dump(None),
+        load_default=LineRange().dump(None)
     )
 
     class Meta:
         render_module = YamlRender
 
+    def loads(self, *args, **kwargs) -> Dict:
+        res = super(self.__class__, self).loads(*args, **kwargs)
+        if res is None:
+            raise ValueError("Could not loads")
+        return res
+
+    def load(self, *args, **kwargs) -> Dict:
+        res = super(self.__class__, self).load(*args, **kwargs)
+        if res is None:
+            raise ValueError("Could not load")
+        return res
+
 
 def transform_data(transform_shell_cmd, input_data):
     """Transform the ``input_data`` using the ``transform_shell_cmd``
@@ -91,7 +106,7 @@ def render_code(token, body, stack, loop):
         token["text"] = "File not found"
         token["lang"] = "text"
         raise IgnoredByContrib
-    
+
     with open(full_path, "rb") as f:
         file_data = f.read()
 
