@@ -3,12 +3,19 @@ Defines utilities for testing lookatme
 """
 
 
-import pytest
 import urwid
 
-
-from lookatme.parser import Parser
+import lookatme.config
 import lookatme.tui
+from lookatme.parser import Parser
+
+
+def setup_lookatme(tmpdir, mocker, style=None):
+    mocker.patch.object(lookatme.config, "LOG")
+    mocker.patch("lookatme.config.SLIDE_SOURCE_DIR", new=str(tmpdir))
+
+    if style is not None:
+        mocker.patch("lookatme.config.STYLE", new=style)
 
 
 def assert_render(correct_render, rendered, full_strip=False):
@@ -39,7 +46,7 @@ def render_markdown(markdown, height=50, width=200, single_slide=False):
 
     container = urwid.ListBox([urwid.Text("testing")])
     container.body = contents
-    return list(container.render((width,height)).content())
+    return list(container.render((width, height)).content())
 
 
 def spec_and_text(item):
